==> rdkit_201903.1.orig.tar.xz: rdkit-Release_2019_03_1/Code/PgSQL/rdkit/cache.h <==
// $Id$
//
//  Copyright (c) 2010-2015, Novartis Institutes for BioMedical Research Inc.
//  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Novartis Institutes for BioMedical Research Inc.
//       nor the names of its contributors may be used to endorse or promote
//       products derived from this software without specific prior written
//       permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
#include <RDGeneral/export.h>
#ifndef _RDKIT_CACHE_H_
#define _RDKIT_CACHE_H_

#ifdef __cplusplus
extern "C" {
#endif


/*
 *  Cache subsystem. Molecules and fingerprints I/O is extremely expensive.
 */
struct MemoryContextData; /* forward declaration to prevent conflicts with C++
                             */
  
void *searchMolCache(void *cache, struct MemoryContextData *ctx, Datum a,
                     Mol **m, CROMol *mol, bytea **sign);
  
void *searchBfpCache(void *cache, struct MemoryContextData *ctx, Datum a,
		     Bfp **f, CBfp *fp, BfpSignature **sign);
  
void *searchSfpCache(void *cache, struct MemoryContextData *ctx, Datum a,
		     Sfp **f, CSfp *fp, bytea **sign);

void *searchReactionCache(void *cache, struct MemoryContextData *ctx,
			  Datum a, Reaction **r,
			  CChemicalReaction *rxn, bytea **sign);

#ifdef __cplusplus
}
#endif
#endif

==> rdkit_201909.1.orig.tar.xz: rdkit-Release_2019_09_1/Code/PgSQL/rdkit/cache.h <==
// $Id$
//
//  Copyright (c) 2010-2015, Novartis Institutes for BioMedical Research Inc.
//  All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
//     * Redistributions of source code must retain the above copyright
//       notice, this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above
//       copyright notice, this list of conditions and the following
//       disclaimer in the documentation and/or other materials provided
//       with the distribution.
//     * Neither the name of Novartis Institutes for BioMedical Research Inc.
//       nor the names of its contributors may be used to endorse or promote
//       products derived from this software without specific prior written
//       permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//
#include <RDGeneral/export.h>
#ifndef _RDKIT_CACHE_H_
#define _RDKIT_CACHE_H_

#ifdef __cplusplus
extern "C" {
#endif

/*
 *  Cache subsystem. Molecules and fingerprints I/O is extremely expensive.
 */
struct MemoryContextData; /* forward declaration to prevent conflicts with C++
                           */

void *searchMolCache(void *cache, struct MemoryContextData *ctx, Datum a,
                     Mol **m, CROMol *mol, bytea **sign);

void *searchBfpCache(void *cache, struct MemoryContextData *ctx, Datum a,
                     Bfp **f, CBfp *fp, BfpSignature **sign);

void *searchSfpCache(void *cache, struct MemoryContextData *ctx, Datum a,
                     Sfp **f, CSfp *fp, bytea **sign);

void *searchReactionCache(void *cache, struct MemoryContextData *ctx, Datum a,
                          Reaction **r, CChemicalReaction *rxn, bytea **sign);

#ifdef __cplusplus
}
#endif
#endif
